//! A ray tracing library based on the book
//! [The Ray Tracer Challenge](https://pragprog.com/titles/jbtracer/the-ray-tracer-challenge/),
//! by Jamis Buck.

pub mod camera;
pub mod canvas;
pub mod color;
pub mod intersection;
pub mod light;
pub mod material;
pub mod matrix;
pub mod ray;
pub mod shape;
pub mod tuple;
pub mod world;
